==> mautic_eca-1.0.2.zip: mautic_eca/src/Plugin/Action/MauticDeleteContact.php <==
<?php

declare(strict_types=1);

namespace Drupal\mautic_eca\Plugin\Action;

use Drupal\Core\Form\FormStateInterface;

/**
 * Action to delete a contact in Mautic.
 *
 * @Action(
 *   id = "mautic_eca_delete_contact",
 *   label = @Translation("Mautic: Delete Contact"),
 *   description = @Translation("Delete a contact for the selected Mautic connection.")
 * )
 */
class MauticDeleteContact extends MauticActionBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return [
      'mautic_id' => '',
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    $form = parent::buildConfigurationForm($form, $form_state);

    $form['mautic_id'] = [
      '#type' => 'number',
      '#title' => $this->t('Mautic ID'),
      '#description' => $this->t('Enter the mautic ID of the contact to delete.'),
      '#default_value' => $this->configuration['mautic_id'],
      '#required' => TRUE,
      '#min' => 1,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state): void {
    $this->configuration['mautic_id'] = $form_state->getValue('mautic_id');
    parent::submitConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function execute(): void {
    try {
      $connectionId = $this->configuration['mautic_connection'];
      $mauticContactId = $this->tokenService->replaceClear($this->configuration['mautic_id']);

      /** @var \Drupal\mautic_api\Entity\MauticApiConnection $connection */
      $connection = $this->entityTypeManager
        ->getStorage('mautic_api_connection')
        ->load($connectionId);

      if (!$connection) {
        $this->logger->error('Mautic connection with ID @id not found', [
          '@id' => $connectionId,
        ]);
        return;
      }

      // Get the API object for contacts.
      $api = $this->mauticApiConnector->getApi($connection);

      // Delete the contact using the API.
      $response = $api->delete($mauticContactId);

      if ($response && !isset($response['errors'])) {
        $this->tokenService->addTokenData($this->configuration['token_name'], $response);
        $this->logger->info('Successfully deleted the Mautic contact with the ID: @id', [
          '@id' => $mauticContactId,
        ]);
      }
    }
    catch (\Exception $e) {
      $this->logger->error('Failed to delete Mautic contact: @error', [
        '@error' => $e->getMessage(),
      ]);
    }
  }

}

==> mautic_eca-1.0.6.zip: mautic_eca/src/Plugin/Action/MauticDeleteContact.php <==
<?php

declare(strict_types=1);

namespace Drupal\mautic_eca\Plugin\Action;

use Drupal\Core\Action\Attribute\Action;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\eca\Attribute\EcaAction;

/**
 * Action to delete a contact in Mautic.
 */
#[Action(
  id: 'mautic_eca_delete_contact',
  label: new TranslatableMarkup('Mautic: Delete Contact'),
)]
#[EcaAction(
  description: new TranslatableMarkup('Delete a contact for the selected Mautic connection.'),
)]
class MauticDeleteContact extends MauticActionBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return [
      'mautic_id' => '',
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    $form = parent::buildConfigurationForm($form, $form_state);

    $form['mautic_id'] = [
      '#type' => 'number',
      '#title' => $this->t('Mautic ID'),
      '#description' => $this->t('Enter the mautic ID of the contact to delete.'),
      '#default_value' => $this->configuration['mautic_id'],
      '#required' => TRUE,
      '#min' => 1,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state): void {
    $this->configuration['mautic_id'] = $form_state->getValue('mautic_id');
    parent::submitConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function execute(): void {
    try {
      $connectionId = $this->configuration['mautic_connection'];
      $mauticContactId = $this->tokenService->replaceClear($this->configuration['mautic_id']);

      /** @var \Drupal\mautic_api\Entity\MauticApiConnection|null $connection */
      $connection = $this->entityTypeManager
        ->getStorage('mautic_api_connection')
        ->load($connectionId);

      if (!$connection) {
        $this->logger->error('Mautic connection with ID @id not found', [
          '@id' => $connectionId,
        ]);
        return;
      }

      // Get the API object for contacts.
      $api = $this->mauticApiConnector->getApi($connection);

      // Delete the contact using the API.
      $response = $api->delete($mauticContactId);

      if ($response && !isset($response['errors'])) {
        $this->tokenService->addTokenData($this->configuration['token_name'], $response);
        $this->logger->info('Successfully deleted the Mautic contact with the ID: @id', [
          '@id' => $mauticContactId,
        ]);
      }
    }
    catch (\Exception $e) {
      $this->logger->error('Failed to delete Mautic contact: @error', [
        '@error' => $e->getMessage(),
      ]);
    }
  }

}
